@@ -301,7 +301,7 @@ xcRenderColorplane(int obj)
 static void
 DrawColorPlane(int obj)
 {
-  register int n, m, j, k, ii;
+  register int n, m, j, k;
   float midC[4], midP[3];
 
   
