@@ -394,6 +394,31 @@ extern NEW_WIN_CONTEXT *FindWinContextByTogl(struct Togl *togl);
 
 
 #ifndef WIN32 
+static int 
+XErrorFunction(Display *display,XErrorEvent *event)
+{
+  char buffer[512];
+  
+  buffer[0]='\0';
+  XGetErrorText(display,event->error_code,buffer,sizeof(buffer)-1);
+  buffer[511]='\0';
+  fprintf(stderr,"X Error of failed request: %s\n",buffer);
+  fprintf(stderr,"    Major opcode of failed request: %d\n",event->request_code);
+  switch(event->error_code) {
+    case BadValue:
+      fprintf(stderr,"    Value in failed request: 0x%x\n",event->resourceid);
+      break;
+    case BadAtom:
+      fprintf(stderr,"    AtomID in failed request: 0x%x\n",event->resourceid);
+      break;
+    default:
+      if (event->error_code != BadRequest)
+        fprintf(stderr,"    ResourceID in failed request: 0x%x\n",event->resourceid);
+      break;
+  }
+  fprintf(stderr,"    Serial number of failed request: %d\n",event->serial);
+  return 0;
+}
 
 /*****************************************************************************/
 int
@@ -409,6 +434,7 @@ main(int argc, char *argv[])
   xcFPEHandler();
 #endif
 
+  XSetErrorHandler(XErrorFunction);
   Tk_Main(argc, argv, Tcl_AppInit);
   exit(0);
 }
@@ -2487,10 +2513,10 @@ int XC_RotationMatrixCmd(ClientData clientData, Tcl_Interp *interp,
   
   if ( strcmp(argv[1], "get") == 0 ) 
     {
-      char *string = calloc(25, sizeof(char));
+      char *string = calloc(30, sizeof(char));
       
       for (i=0; i<16; i++) {
-	sprintf(string,"%22.15e ",vec.crdvec[i]);
+	sprintf(string, "%22.15e ",vec.crdvec[i]);
 	Tcl_AppendResult(interp, string, (char*)NULL);
       }
 
@@ -2538,13 +2564,14 @@ int XC_TranslParamCmd(ClientData clientData, Tcl_Interp *interp,
 		      int argc, char *argv[])
 {
   int i;
-  char string[23];
   
   if ( strcmp(argv[1], "get") == 0 ) 
     {
+      char *string = calloc(30, sizeof(char));           
       sprintf(string, "%22.15e ", tr.xtransl); Tcl_AppendResult(interp, string, (char*)NULL);
       sprintf(string, "%22.15e ", tr.ytransl); Tcl_AppendResult(interp, string, (char*)NULL);
       sprintf(string, "%22.15e ", tr.zoom);    Tcl_AppendResult(interp, string, (char*)NULL);
+      free( (FREE_ARG) string);
     }
   else if ( strcmp(argv[1], "set") == 0 ) 
     {
