@@ -1282,6 +1282,7 @@ XC_IsofilesCmd(ClientData clientData, Tcl_Interp *interp,
   */
   fprintf(stderr, "c95_version-1\n"); fflush(stderr);
   version = Tcl_GetVar2(interp, "system", "c95_version", TCL_GLOBAL_ONLY);
+
   if ( strncmp("95",version,2) == 0 ) {
     crystal_version = 95;
   } 
@@ -1289,14 +1290,17 @@ XC_IsofilesCmd(ClientData clientData, Tcl_Interp *interp,
     crystal_version = 98;
   }
   else if ( strncmp("03",version,2) == 0 ) {
-    crystal_version = 03;
+    crystal_version = 3;
   } 
   else if ( strncmp("06",version,2) == 0 ) {
-    crystal_version = 06;
+    crystal_version = 6;
   } 
   else if ( strncmp("09",version,2) == 0 ) {
     crystal_version = 9;
   } 
+  else if ( strncmp("14",version,2) == 0 ) {
+    crystal_version = 14;
+  } 
   else {
     crystal_version = 0;
   }
@@ -1688,7 +1692,8 @@ XC_IsodataCmd(ClientData clientData, Tcl_Interp *interp,
       /* range was specified */
       first = strcspn(argv[i],"-");
       strncpy(fint,argv[i],first);
-      fint[first] = (char) NULL;
+      /*fint[first] = (char) NULL;*/
+      fint[first] = ' ';
       strcpy(sint,&argv[i][first+1]);
       if ( Tcl_GetInt(interp, fint, &(framenum[which_time][i-1][0])) == 
 	   TCL_ERROR ) {
