@@ -67,9 +67,9 @@ proc SelAtomLabel {t type elem title text i} {
     set grab 0
     if { [grab current] == $t } {
 	set grab 1
-	grab release $t
+	catch { grab release $t }
     }
-    puts stdout "GRAB IS> [grab status $t]"
+
     set selwin [PreSel .selatom .mesa $title $text LabelSel 1]
     tkwait variable SelLabel(done)
 
@@ -84,7 +84,7 @@ proc SelAtomLabel {t type elem title text i} {
 	set atomDisp(${elem},${i}) $SelLabel(label)
     }
     if { $grab } {
-	grab $t
+	catch { grab $t }
     }
 }    
 
@@ -108,7 +108,7 @@ proc LabelSel {{w {}}} {
 
     xcDebug -stderr "Executing: $com"
     if { [catch {set label [string trim [eval $com]]} errmsg] } {
-	error "error executing atomlab"
+	error "error executing atomlab: $errmsg"
 	$select(textWid) delete [expr $maxsel + 4].0 [expr $maxsel + 4].end
 	$select(textWid) insert [expr $maxsel + 4].0 $errmsg
 	file delete $system(SCRDIR)/xc_tmp.$system(PID)
@@ -167,7 +167,7 @@ proc AtomRemo {} {
     
     pack $fb2.butok $fb2.butcan -side left \
 	    -expand 1 -padx 10
-    #grab $t
+
     tkwait window $t
 }
 
@@ -331,7 +331,7 @@ proc AtomInse {} {
     
     pack $fb3.butok $fb3.butcan -side left \
 	    -expand 1 -padx 10 -pady 10
-    #grab $t
+
     tkwait window $t
 }
 
@@ -341,7 +341,7 @@ proc AddAtom {t i} {
 	    atompos system af bf cf
     
     set SelHoleCL(transl) 1
-    #grab release $t
+
     # atomInse(how2) can be Hole-Adding or Cell-Adding
     if { $atomInse(how2) == "Hole-Adding" } {
 	# here I will use "SelCentreHoleCL" proc that was designd 
@@ -385,7 +385,6 @@ proc AddAtom {t i} {
 	    tk_dialog .dialog ERROR \
 		    "Wrong dimensionality of structure. Goodbye!!!" \
 		    error 0 OK
-	    #grab $t
 	    return
 	}
 	
@@ -437,7 +436,6 @@ proc AddAtom {t i} {
 	set atomInse(Y,$i) [lindex $coor 1]
 	set atomInse(Z,$i) [lindex $coor 2]	
     }
-    #grab $t
 }
 
 
@@ -533,7 +531,6 @@ proc SuperCell {} {
 
     set t [xcToplevel [WidgetName] "Generation of a SuperCell" \
 	    "SuperCell" . 180 0 1]
-    #grab $t
 
     set f1 [frame $t.f1 -highlightthickness 0]
     set f2 [frame $t.f2 -relief raised -bd 2 -highlightthickness 0]
@@ -824,7 +821,7 @@ proc AtomDisp {} {
     
     pack $fb.butok $fb.butcan -side left \
 	    -expand 1 -padx 10 -pady 10
-    #grab $t
+
     tkwait window $t
 }
 
@@ -855,7 +852,6 @@ proc Elastic {} {
 
     set t [xcToplevel [WidgetName] "Elastic Deformation" \
 	    "Elastic" . 180 0 1]
-    #grab $t
 
     set elastic(type) Z_vol
     set elastic(varlist) {}
@@ -1070,7 +1066,6 @@ proc RotFrame {} {
 
     set t [xcToplevel [WidgetName] "Rotate Cartesian Frame" \
 	    "Rotate" . 180 0 1]
-    #grab $t
 
     set rotFrame(varlist) {}
     set rotFrame(foclist) {}
