@@ -555,9 +555,9 @@ proc AlwaysOnTopOFF {{lower {.}}} {
 
 proc CancelProc {w {var {}}} {
     upvar $var varn
-    if [winfo exists $w] {
+    if { [winfo exists $w] } {
 	AlwaysOnTopOFF
-	grab release $w
+	catch { grab release $w }
 	destroy $w
     }
     set varn 0
