@@ -49,7 +49,7 @@ proc Bz_MakeToplevel {{what {}}} {
 			  "*** XCrySDen *** K-path selection: $dir" \
 			  "Path Selection" . 290 000 1]
     }
-    grab $Bz(tplw)
+    catch { grab $Bz(tplw) }
     wm resizable $Bz(tplw) 0 0
     
     set f1 [frame $Bz(tplw).f1 -highlightthickness 0]
@@ -668,7 +668,7 @@ proc Bz_OK {can type} {
 	#/
     }
     
-    grab release $Bz(tplw)
+    catch { grab release $Bz(tplw) }
     if { $Bz(tplw) != "." } {
 	destroy $Bz(tplw)
     }
@@ -676,7 +676,7 @@ proc Bz_OK {can type} {
     # maybe user want's to modify something
     set t [xcToplevel [WidgetName] "Band Structure Script" \
 	    "BAND" . 100 100 1]
-    grab $t
+    catch { grab $t }
 
     set f1 [frame $t.f1 -relief raised -bd 2]    
     set f2 [frame $t.f2 -relief raised -bd 2]
@@ -874,7 +874,8 @@ proc Bz_OK_OK {tplw type coor_label} {
     xcDebug -stderr "--------------------------------"
     xcDebug -stderr $prop(c95_BAND_script)
 
-    grab release $tplw
+    catch { grab release $tplw }
+
     destroy $tplw
     set BzOK(done) 1
 }
