@@ -9,7 +9,7 @@
 #                                                                           #
 # Source: $XCRYSDEN_TOPDIR/Tcl/menu.tcl                                       
 # ------                                                                    #
-# Copyright (c) 1996-2003 by Anton Kokalj                                   #
+# Copyright (c) 1996-2014 by Anton Kokalj                                   #
 #############################################################################
 
 
@@ -101,13 +101,13 @@ proc mainMenu {can mcolor mfile mmod mdis madvg mpro mdat mhelp} {
     # FILE MENU
     #------------------------------------------------------------------------
 
-    $mfile add command -label "New CRYSTAL-95/98/03/06 Input" -command new_file 
+    $mfile add command -label "New CRYSTAL Input" -command new_file 
     $mfile add separator
     #$mfile add command -label "Open Structure" \
     #	     -command [list OpenStruct $can]
     $mfile add cascade -label "Open Structure ..."        -menu $mfile.opstr
     $mfile add cascade -label "Open PWscf ..."            -menu $mfile.pwscf 
-    $mfile add cascade -label "Open CRYSTAL-95/98/03/06 ..." -menu $mfile.crystal
+    $mfile add cascade -label "Open CRYSTAL ..." -menu $mfile.crystal
     $mfile add cascade -label "Open WIEN2k ..."           -menu $mfile.wien
     #$mfile add command -label "Band Path Selection - Test" \
     #	      -command Bz_MakeToplevel
@@ -122,7 +122,7 @@ proc mainMenu {can mcolor mfile mmod mdis madvg mpro mdat mhelp} {
     bind . <Control-s> SaveStruct
     bind . <Control-Alt-s> saveState
 
-    $mfile add command -label "Save CRYSTAL-95/98/03/06 Input" \
+    $mfile add command -label "Save CRYSTAL Input" \
 	    -command SaveCrystalInput
     $mfile add command -label "Save WIEN2k Struct File" -command wnSaveSFile
     $mfile add separator
@@ -213,8 +213,8 @@ proc mainMenu {can mcolor mfile mmod mdis madvg mpro mdat mhelp} {
 
     # Open CRYSTAL-95/98/03/06 ...
     set crystal [menu $mfile.crystal -tearoff 0]
-    $crystal add command -label "Open CRYSTAL-95/98/03/06 Input"      -command OpenFile
-    $crystal add command -label "Open CRYSTAL-95/98/03/06 Properties (e.g. fort.9)" -command PropC95
+    $crystal add command -label "Open CRYSTAL Input"      -command OpenFile
+    $crystal add command -label "Open CRYSTAL Properties (e.g. fort.9)" -command PropC95
 
     # Open WIEN2k
 
@@ -275,7 +275,7 @@ proc mainMenu {can mcolor mfile mmod mdis madvg mpro mdat mhelp} {
     $exam add separator
     #--------------------
     
-    $exam add command -label "CRYSTAL-95/98/03/06 Input Files" \
+    $exam add command -label "CRYSTAL Input Files" \
 	-command {
 	    OpenFile $system(TOPDIR)/examples/CRYSTALxx_input_files 
 	}
@@ -647,7 +647,7 @@ proc mainMenu {can mcolor mfile mmod mdis madvg mpro mdat mhelp} {
     #$mmod add command -label "Screen Factor" \
     #	     -command [list ModFactor Screen L_SCRF D_SCRF]
     $mmod add separator
-    $mmod add command -label "Number of Units drawn" -command NumCellDrawn -accelerator "Shift-n"
+    $mmod add command -label "Number of Units Drawn" -command NumCellDrawn -accelerator "Shift-n"
     bind . <N> NumCellDrawn
 
 
@@ -1928,11 +1928,14 @@ proc ToggleMenuCheckbutton {which args} {
 }
 
 proc ToggleMenuRadiobutton {which value args} {
-    global radio
-    set radio($which) $value
-    SetWatchCursor
-    eval $args
-    ResetCursor
+    global radio periodic
+
+    if { $periodic(dim) > 0 } { 
+	set radio($which) $value
+	SetWatchCursor
+	eval $args
+	ResetCursor
+    }
 }
 
 
