@@ -258,7 +258,7 @@ proc CheckGroup {{act {}}} {
 	if { [lindex $groupsel 0] == "R" } {
 	    # query for rhombo./hexa. axes
 	    xcToplevel .ifhr "IFHR" "IFHR" . 120 70 1
-	    grab .ifhr
+	    catch { grab .ifhr }
 	    
 	    frame .ifhr.frame -relief raised -bd 2
 	    label .ifhr.frame.lab -text "Select the type of cell for\n\
@@ -489,7 +489,7 @@ proc set_origin {} {
     global var button inp
 
     xcToplevel .ifso "Origin Settings" "Origin Settings" . 120 70 1
-    grab .ifso
+    catch { grab .ifso }
 
     frame .ifso.frame -relief raised -bd 2
     pack .ifso.frame -side top -fill both -padx 1 -pady 1
@@ -530,7 +530,7 @@ proc orig_coord {} {
     global inp ok err geo
 
     xcToplevel .orig_coord "Origin Shift" "Origin Shift" . 120 70 1
-    grab .orig_coord
+    catch { grab .orig_coord }
     # this procedure create toplevel, where coord. of origin-shift 
     # will be specified
     
@@ -560,7 +560,7 @@ proc n_atoms {} {
     # NATR -number of non. eq. atoms
 
     xcToplevel .natom "N. of Atoms" "N. of Atoms" . 120 70 1
-    grab .natom
+    catch { grab .natom }
 
     frame .natom.top -relief raised -bd 1
     frame .natom.bot
@@ -601,7 +601,7 @@ proc atom_num_coord {} {
 		non-equivalent atoms" warning 0 OK	
     } else {
 	xcToplevel .atom "Atom Coordinates" "Atom Coordinates" . 120 70 1
-	grab .atom
+	catch { grab .atom }
 
 	# bottom frame where OK button will be
 	set Frm [frame .atom.frame]
