@@ -940,7 +940,7 @@ proc scripting::rotate {dir args} {
 # ------------------------------------------------------------------------
 
 proc scripting::printToFile {{filename {}} {windowdump {}} {togl .mesa}} {
-    global xcMisc system printSetup light
+    global xcMisc system printSetup light toglEPS
     
     #
     # check if we have converting program
@@ -974,7 +974,13 @@ proc scripting::printToFile {{filename {}} {windowdump {}} {togl .mesa}} {
 	    #
 	    # ligting-OFF mode
 	    #
-	    $togl cry_gl2psPrintTogl GL2PS_EPS GL2PS_NO_SORT \
+	    if { ! [info exists toglEPS(pointsize)] } {
+		set toglEPS(pointsize) 2.0
+	    }
+	    if { ! [info exists toglEPS(linewidth)] } {
+		set toglEPS(linewidth) 2.0
+	    }
+	    $togl cry_gl2psPrintTogl GL2PS_EPS GL2PS_NO_SORT GL2PS_NONE \
 		$toglEPS(pointsize) $toglEPS(linewidth) $filename
 	}
     } else {
