@@ -9,7 +9,7 @@
 #                                                                           #
 # Source: $XCRYSDEN_TOPDIR/Tcl/state.tcl                                       
 # ------                                                                    #
-# Copyright (c) 1996-2003 by Anton Kokalj                                   #
+# Copyright (c) 1996-2014 by Anton Kokalj                                   #
 #############################################################################
 
 ##############################################################################
@@ -191,15 +191,15 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 
     # disable all entries but exit&print-setup-entry in file-menu 
     foreach entry { 
-	{New CRYSTAL-95/98/03/06 Input} 
+	{New CRYSTAL Input} 
 	{Open Structure ...} 
 	{Open PWscf ...} 
-	{Open CRYSTAL-95/98/03/06 ...} 
+	{Open CRYSTAL ...} 
 	{Open WIEN2k ...} 
 	Close 
 	{Save XSF Structure} 
 	{Save Current State and Structure}
-	{Save CRYSTAL-95/98/03/06 Input} 
+	{Save CRYSTAL Input} 
 	{Save WIEN2k Struct File} 
 	Print* 
 	{XCrySDen Examples ...}
@@ -228,10 +228,10 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 
 	# in file menu enable new*/open* entries
 	foreach entry { 
-	    {New CRYSTAL-95/98/03/06 Input} 
+	    {New CRYSTAL Input} 
 	    {Open Structure ...} 
 	    {Open PWscf ...} 
-	    {Open CRYSTAL-95/98/03/06 ...}
+	    {Open CRYSTAL ...}
 	    {Open WIEN2k ...} 
 	    {XCrySDen Examples ...}
 	} {
@@ -363,7 +363,7 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 	    Close 
 	    {Save XSF Structure} 
 	    {Save Current State and Structure}
-	    {Save CRYSTAL-95/98/03/06 Input} 
+	    {Save CRYSTAL Input} 
 	} {
 	    $menu.vmfile${menu2} entryconfig $entry -state normal
 	}
@@ -375,7 +375,7 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
 	    Close 
 	    {Save XSF Structure} 
 	    {Save Current State and Structure}
-	    {Save CRYSTAL-95/98/03/06 Input} 
+	    {Save CRYSTAL Input} 
 	    {Save WIEN2k Struct File} 
 	} {
 	    $menu.vmfile${menu2} entryconfig $entry -state normal
@@ -434,19 +434,19 @@ proc xcUpdateState {{menu .menu} {menu2 .menu}} {
     }
     
     if { $periodic(dim) == 0 } {
-	$menu.vmmod${menu2} entryconfig {Number of Units drawn} -state disabled
+	$menu.vmmod${menu2} entryconfig {Number of Units Drawn} -state disabled
 	.mea.f2.unit config -state disabled
 	.mea.f2.asym config -state disabled
     } else {
-	$menu.vmmod${menu2} entryconfig {Number of Units drawn} -state normal
+	$menu.vmmod${menu2} entryconfig {Number of Units Drawn} -state normal
 	.mea.f2.unit config -state active
 	.mea.f2.asym config -state active
     }
     
     if { $system(c95_exist) == 0 } {
 	foreach entry { 
-	    {New CRYSTAL-95/98/03/06 Input} 
-	    {Open CRYSTAL-95/98/03/06 ...} 
+	    {New CRYSTAL Input} 
+	    {Open CRYSTAL ...} 
 	} {
 	    $menu.vmfile${menu2} entryconfig $entry -state disabled
 	}
